- formula
formula. The response is on the left of a ~ operator. The terms are on the right of a ~ operator, separated by a + operator.
- data
an optional data frame containing variables in the model.
- gamma_0
numeric. A tuning parameter for the learning rate (gamma_0 x t ^ alpha). Default is NULL and it is determined by the adaptive method: 1/sd(y).
- alpha
numeric. A tuning parameter for the learning rate (gamma_0 x t ^ alpha). Default is 0.501.
- burn
numeric. A tuning parameter for "burn-in" observations.
We burn-in up to (burn-1) observations and use observations from (burn) for estimation. Default is 1, i.e. no burn-in.
- bt_start
numeric. (p x 1) vector, excluding the intercept term. User-provided starting value. Default is NULL.
- studentize
logical. Studentize regressors. Default is TRUE.
- no_studentize
numeric. The number of observations to compute the mean and std error for studentization. Default is 100.
- intercept
logical. Use the intercept term for regressors. Default is TRUE.
If this option is TRUE, the first element of the parameter vector is the intercept term.
- path
logical. The whole path of estimation results is out. Default is FALSE.
- path_index
numeric. A vector of indices to print out the path. Default is 1.